#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.mec_mod_interfaces.face import Face


class PlanarFace(Face):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Reference
                |                         MecModInterfaces.Boundary
                |                             MecModInterfaces.Face
                |                                 PlanarFace
                | 
                | 2-D boundary with a planar geometry.
                | Role: This Boundary object may be, for example, the face of a
                | cube.
                | You will create a PlanarFace object using the Shapes.GetBoundary ,
                | HybridShapes.GetBoundary , Sketches.GetBoundary or Selection.SelectElement2
                | method. Then, you pass it to the operator (such as ShapeFactory.AddNewDraft
                | ).
                | The lifetime of a PlanarFace object is limited, see Boundary.
                | 
                | Example:
                |     This example asks the end user to select a face and two planar faces, and
                |     creates a draft on these faces:
                | 
                |      Dim InputObjectType(0)
                |      Set Document = CATIA.ActiveDocument
                |      Set Selection = Document.Selection
                |      'We propose to the user that he select the face to draft
                |      InputObjectType(0)="Face"
                |      Status=Selection.SelectElement2(InputObjectType,"Select the face to
                |      draft",true)
                |      if (Status = "cancel") then Exit Sub
                |      Set FaceToDraft = Selection.Item(1).Value
                |      Selection.Clear
                |      'We propose to the user that he select the neutral face
                |      InputObjectType(0)="PlanarFace"
                |      Status=Selection.SelectElement2(InputObjectType,"Select the neutral
                |      face",true)
                |      if (Status = "cancel") then Exit Sub
                |      Set NeutralFace = Selection.Item(1).Value
                |      Selection.Clear
                |      'We propose to the user that he select the parting
                |      element
                |      InputObjectType(0)="PlanarFace"
                |      Status=Selection.SelectElement2(InputObjectType,"Select the parting
                |      element",true)
                |      if (Status = "cancel") then Exit Sub
                |      Set PartingElement = Selection.Item(1).Value
                |      Set Draft = ShapeFactory.AddNewDraft(
                |                      FaceToDraft,NeutralFace,0,PartingElement,0.0,0.0,1.0,0,5.0,0
                |                  )
                |      Set DraftDomains = Draft.DraftDomains
                |      Set DraftDomain = DraftDomains.Item(1)
                |      DraftDomain.SetPullingDirection 0.0, 0.0,1.0
                |      Document.Part.Update
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.planar_face = com_object

    def get_first_axis(self, o_first_axis: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetFirstAxis(CATSafeArrayVariant oFirstAxis)
                | 
                |     Returns the planar face first axis
                | 
                |     Parameters:
                | 
                |         oFirstAxis[0]
                |             The X Coordinate of the planar face first axis 
                |         oFirstAxis[1]
                |             The Y Coordinate of the planar face first axis 
                |         oFirstAxis[2]
                |             The Z Coordinate of the planar face first axis

        :param tuple o_first_axis:
        :return: None
        :rtype: None
        """
        return self.planar_face.GetFirstAxis(o_first_axis)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_first_axis'
        # # vba_code = """
        # # Public Function get_first_axis(planar_face)
        # #     Dim oFirstAxis (2)
        # #     planar_face.GetFirstAxis oFirstAxis
        # #     get_first_axis = oFirstAxis
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_origin(self, o_origin: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetOrigin(CATSafeArrayVariant oOrigin)
                | 
                |     Returns the origin of the planar face.
                | 
                |     Parameters:
                | 
                |         oOrigin[0]
                |             The X Coordinate of the planar face origin 
                |         oOrigin[1]
                |             The Y Coordinate of the planar face origin 
                |         oOrigin[2]
                |             The Z Coordinate of the planar face origin

        :param tuple o_origin:
        :return: None
        :rtype: None
        """
        return self.planar_face.GetOrigin(o_origin)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_origin'
        # # vba_code = """
        # # Public Function get_origin(planar_face)
        # #     Dim oOrigin (2)
        # #     planar_face.GetOrigin oOrigin
        # #     get_origin = oOrigin
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_second_axis(self, o_second_axis: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetSecondAxis(CATSafeArrayVariant oSecondAxis)
                | 
                |     Returns the planar face second axis.
                | 
                |     Parameters:
                | 
                |         oSecondAxis[0]
                |             The X Coordinate of the planar face second axis 
                |         oSecondAxis[1]
                |             The Y Coordinate of the planar face second axis 
                |         oSecondAxis[2]
                |             The Z Coordinate of the planar face second axis

        :param tuple o_second_axis:
        :return: None
        :rtype: None
        """
        return self.planar_face.GetSecondAxis(o_second_axis)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_second_axis'
        # # vba_code = """
        # # Public Function get_second_axis(planar_face)
        # #     Dim oSecondAxis (2)
        # #     planar_face.GetSecondAxis oSecondAxis
        # #     get_second_axis = oSecondAxis
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'PlanarFace(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class ProjectedToleranceZone(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ProjectedToleranceZone
                | 
                | Interface for accessing projected tolerance zone informations of a
                | TPS.
                | ========| Position Length / |<----------->|<----------->| Toleranced | | |
                | Surface - - - +-------> +=============+ \ |\ \ \ \ | Origin Direction Projected
                | Tolerance Zone ========
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.projected_tolerance_zone = com_object

    @property
    def length(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Length() As double (Read Only)
                | 
                |     Retrieves length of the projected tolerance zone (in millimeters). The
                |     length defines the ending point of the tolerance zone. This point can be
                |     computed by using Origin and Direction of the axis.

        :return: float
        :rtype: float
        """

        return self.projected_tolerance_zone.Length

    @property
    def position(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Position() As double (Read Only)
                | 
                |     Retrieves position of the projected tolerance zone (in millimeters). The
                |     position defines the starting point of the tolerance zone. This point can be
                |     computed by using Origin and Direction of the axis.

        :return: float
        :rtype: float
        """

        return self.projected_tolerance_zone.Position

    def get_projected_tol_zone_reference(self, op_reference: tuple) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetProjectedTolZoneReference(CATSafeArrayVariant
                | opReference)
                | 
                |     Retrieves reference axis of the projected tolerance zone. The returned
                |     point and vector define a axis system that is used to defined the 3D position
                |     of the tolerance zone.
                | 
                |     Parameters:
                | 
                |         opReference
                |             The first 3 values of opReference correspond to the X,Y and Z
                |             values of the origin point respectively and the next 3 values correspond to the
                |             X,Y and Z values of the direction respectively. 
                | 
                |     Example:
                | 
                |           This example gets the Projected Tolerance Zone reference in a VB
                |           Script
                |          Dim oTab(6) As CATSafeArrayVariant
                |          Set projTol = annotation.ProjectedToleranceZone
                |           projTol.GetProjectedTolZoneReference(oTab)
                |           oStream.Write "Projected Tol Zone Reference Point : " & oTab(0) & " " & oTab(1) & " " & oTab(2) & sLF
                |           oStream.Write "Projected Tol Zone Reference Vector : " & oTab(3) & " " & oTab(4) & " " & oTab(5) & sLF

        :param tuple op_reference:
        :return: tuple
        :rtype: tuple
        """
        return self.projected_tolerance_zone.GetProjectedTolZoneReference(op_reference)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_projected_tol_zone_reference'
        # # vba_code = """
        # # Public Function get_projected_tol_zone_reference(projected_tolerance_zone)
        # #     Dim opReference (2)
        # #     projected_tolerance_zone.GetProjectedTolZoneReference opReference
        # #     get_projected_tol_zone_reference = opReference
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ProjectedToleranceZone(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.reference import Reference

from pycatia.mec_mod_interfaces.shape import Shape
from pycatia.sketcher_interfaces.sketch import Sketch


class SketchBasedShape(Shape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         SketchBasedShape
                | 
                | Represents the shapes based on sketched 2D geometry.
                | It is the base object for prisms, holes, revolutions, stiffeners, and
                | sweeps.
                | 
                | See also:
                |     Prism, Hole, Revolution, Stiffener, Sweep
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sketch_based_shape = com_object

    @property
    def sketch(self) -> Sketch:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Sketch() As Sketch (Read Only)
                | 
                |     Returns the sketch the shape is based on.
                | 
                |     Example:
                |         The following example returns the sketch a pad named firstPad is based
                |         on:
                | 
                |          Set sketchPad = firstPad.Sketch

        :return: Sketch
        :rtype: Sketch
        """

        return Sketch(self.sketch_based_shape.Sketch)

    def set_profile_element(self, i_profile_element: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetProfileElement(Reference iProfileElement)
                | 
                |     Returns or sets a profile element.

        :param Reference i_profile_element:
        :return: None
        :rtype: None
        """
        return self.sketch_based_shape.SetProfileElement(i_profile_element.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_profile_element'
        # # vba_code = """
        # # Public Function set_profile_element(sketch_based_shape)
        # #     Dim iProfileElement (2)
        # #     sketch_based_shape.SetProfileElement iProfileElement
        # #     set_profile_element = iProfileElement
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SketchBasedShape(name="{self.name}")'



#! /usr/bin/python3.9

import logging

from pycatia.cat_logger import create_logger


class PyCATIA:
    """
    Base class for the catia application.
    """

    def __init__(self):
        pass

    @property
    def logger(self) -> logging.Logger:
        """
        :return: logging.Logger
        :rtype: logging.Logger
        """
        return create_logger()

    def __repr__(self):
        return 'PyCATIA()'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeSection(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeSection
                | 
                | Interface to hybrid shape section feature.
                | Role: Allows you to access data of the Hybrid Shape Section
                | feature.
                | 
                | See also:
                |     HybridShapeFactory.AddNewSection
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_section = com_object

    @property
    def section_plane(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SectionPlane() As Reference
                | 
                |     Returns or sets the section plane..
                | 
                |     Parameters:
                | 
                |         oPlane
                |             The section oPlane
                | 
                |             Example:
                |                 This example retrieves in RefPlane the plane of the
                |                 section
                | 
                |                  Dim RefPlane As Reference 
                |                  Set RefPlane = HybridShapeSection.SectionPlane

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_section.SectionPlane)

    @section_plane.setter
    def section_plane(self, reference_plane: Reference):
        """
        :param Reference reference_plane:
        """

        self.hybrid_shape_section.SectionPlane = reference_plane.com_object

    def __repr__(self):
        return f'HybridShapeSection(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.funct_system_interfaces.functional_facet import FunctionalFacet
from pycatia.funct_system_interfaces.functional_facet_mgr import FunctionalFacetMgr
from pycatia.funct_system_interfaces.functional_position import FunctionalPosition


class FunctionalObject(FunctionalPosition):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATFunctSystemItf.FunctionalElement
                |                         CATFunctSystemItf.FunctionalPosition
                |                             FunctionalObject
                | 
                | The interface to access a Functional Object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.functional_object = com_object

    def get_facet(self, i_fm: FunctionalFacetMgr) -> FunctionalFacet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetFacet(FunctionalFacetMgr iFM) As FunctionalFacet
                | 
                |     Returns the Facet.

        :param FunctionalFacetMgr i_fm:
        :return: FunctionalFacet
        :rtype: FunctionalFacet
        """
        return FunctionalFacet(self.functional_object.GetFacet(i_fm.com_object))

    def get_facet_by_name(self, i_fm: str) -> FunctionalFacet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetFacetByName(CATBSTR iFM) As FunctionalFacet
                | 
                |     Returns the Facet.

        :param str i_fm:
        :return: FunctionalFacet
        :rtype: FunctionalFacet
        """
        return FunctionalFacet(self.functional_object.GetFacetByName(i_fm))

    def search_facet(self, i_fm: FunctionalFacetMgr, i_create_if_necessary: bool) -> FunctionalFacet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func SearchFacet(FunctionalFacetMgr iFM,
                | boolean iCreateIfNecessary) As FunctionalFacet
                | 
                |     Searches the Facet.

        :param FunctionalFacetMgr i_fm:
        :param bool i_create_if_necessary:
        :return: FunctionalFacet
        :rtype: FunctionalFacet
        """
        return FunctionalFacet(self.functional_object.SearchFacet(i_fm.com_object, i_create_if_necessary))

    def search_facet_by_name(self, i_fm: str, i_create_if_necessary: bool) -> FunctionalFacet:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func SearchFacetByName(CATBSTR iFM,
                | boolean iCreateIfNecessary) As FunctionalFacet
                | 
                |     Searches the Facet.

        :param str i_fm:
        :param bool i_create_if_necessary:
        :return: FunctionalFacet
        :rtype: FunctionalFacet
        """
        return FunctionalFacet(self.functional_object.SearchFacetByName(i_fm, i_create_if_necessary))

    def __repr__(self):
        return f'FunctionalObject(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.funct_system_interfaces.functional_description import FunctionalDescription


class FunctionalVariant(FunctionalDescription):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATFunctSystemItf.FunctionalElement
                |                        
                |                        CATFunctSystemItf.FunctionalDescription
                |                             FunctionalVariant
                | 
                | The interface to access a Functional Variant.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.functional_variant = com_object

    @property
    def original_description(self) -> FunctionalDescription:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property OriginalDescription() As FunctionalDescription (Read
                | Only)
                | 
                |     Returns the Original Description the Variant comes from.

        :return: FunctionalDescription
        :rtype: FunctionalDescription
        """

        return FunctionalDescription(self.functional_variant.OriginalDescription)

    def __repr__(self):
        return f'FunctionalVariant(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class KnowledgeSheetSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         KnowledgeSheetSettingAtt
                | 
                | The interface to access a CATIAKnowledgeSheetSettingAtt.
                | This interface may be used to read or modify in the CATIA/Tools/Option the
                | settings values of Knowledge sheet.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.knowledge_sheet_setting_att = com_object

    @property
    def design_tables_copy_data(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property DesignTablesCopyData() As short
                | 
                |     Returns or sets the DesignTablesCopyData parameter.
                |     Role:Return or Set the DesignTablesCopyData parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         oDesignTablesCopyData
                |             Legal values:
                |             0 : default mode for design table : copy data into models
                |             1 : default mode for design table : do not copy data into models.

        :return: int
        :rtype: int
        """

        return self.knowledge_sheet_setting_att.DesignTablesCopyData

    @design_tables_copy_data.setter
    def design_tables_copy_data(self, value: int):
        """
        :param int value:
        """

        self.knowledge_sheet_setting_att.DesignTablesCopyData = value

    @property
    def design_tables_synchronization(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property DesignTablesSynchronization() As short
                | 
                |     Returns or sets the DesignTablesSynchronization parameter.
                |     Role:Return or Set the DesignTablesSynchronization parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         oDesignTablesSynchronization
                |             Legal values:
                |             0 : automatic synchronization at load for design table
                |             1 : interactive synchronization at load for design table
                |             2 : manual synchronization for design table.

        :return: int
        :rtype: int
        """

        return self.knowledge_sheet_setting_att.DesignTablesSynchronization

    @design_tables_synchronization.setter
    def design_tables_synchronization(self, value: int):
        """
        :param int value:
        """

        self.knowledge_sheet_setting_att.DesignTablesSynchronization = value

    @property
    def parameter_name_surrounded_by_the_symbol(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ParameterNameSurroundedByTheSymbol() As short
                | 
                |     Returns or sets the ParameterNameSurroundedByTheSymbol
                |     parameter.
                |     Role:Return or Set the ParameterNameSurroundedByTheSymbol parameter if it
                |     is possible in the current administrative context. In user mode this method
                |     will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         oParameterNameSurroundedByTheSymbol
                |             Legal values:
                |             0 : to see parameter name not surrounded by the symbol "'"
                |             1 : to see parameter name surrounded by the symbol "'".

        :return: int
        :rtype: int
        """

        return self.knowledge_sheet_setting_att.ParameterNameSurroundedByTheSymbol

    @parameter_name_surrounded_by_the_symbol.setter
    def parameter_name_surrounded_by_the_symbol(self, value: int):
        """
        :param int value:
        """

        self.knowledge_sheet_setting_att.ParameterNameSurroundedByTheSymbol = value

    @property
    def parameter_tree_view_with_formula(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ParameterTreeViewWithFormula() As short
                | 
                |     Returns or sets the ParameterTreeViewWithFormula
                |     parameter.
                |     Role:Return or Set the ParameterTreeViewWithFormula parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         oParameterTreeViewWithFormula
                |             Legal values:
                |             0 : to see parameter tree view without formula
                |             1 : to see parameter tree view with formula.

        :return: int
        :rtype: int
        """

        return self.knowledge_sheet_setting_att.ParameterTreeViewWithFormula

    @parameter_tree_view_with_formula.setter
    def parameter_tree_view_with_formula(self, value: int):
        """
        :param enum value:
        """

        self.knowledge_sheet_setting_att.ParameterTreeViewWithFormula = value

    @property
    def parameter_tree_view_with_value(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ParameterTreeViewWithValue() As short
                | 
                |     Returns or sets the ParameterTreeViewWithValue parameter.
                |     Role:Return or Set the ParameterTreeViewWithValue parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         oParameterTreeViewWithValue
                |             Legal values:
                |             0 : to see parameter tree view without value
                |             1 : to see parameter tree view with value.

        :return: int
        :rtype: int
        """

        return self.knowledge_sheet_setting_att.ParameterTreeViewWithValue

    @parameter_tree_view_with_value.setter
    def parameter_tree_view_with_value(self, value: int):
        """
        :param int value:
        """

        self.knowledge_sheet_setting_att.ParameterTreeViewWithValue = value

    @property
    def relations_update_in_part_context_evaluate_during_update(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property RelationsUpdateInPartContextEvaluateDuringUpdate() As
                | short
                | 
                |     Returns or sets the RelationsUpdateInPartContextEvaluateDuringUpdate
                |     parameter.
                |     Role:Return or Set the RelationsUpdateInPartContextEvaluateDuringUpdate
                |     parameter if it is possible in the current administrative context. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         oRelationsUpdateInPartContextEvaluateDuringUpdate
                |             Legal values:
                |             0 : creation of relations not evaluate during update
                |             1 : creation of relations evaluate during update.

        :return: int
        :rtype: int
        """

        return self.knowledge_sheet_setting_att.RelationsUpdateInPartContextEvaluateDuringUpdate

    @relations_update_in_part_context_evaluate_during_update.setter
    def relations_update_in_part_context_evaluate_during_update(self, value: int):
        """
        :param int value:
        """

        self.knowledge_sheet_setting_att.RelationsUpdateInPartContextEvaluateDuringUpdate = value

    @property
    def relations_update_in_part_context_synchronous_relations(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property RelationsUpdateInPartContextSynchronousRelations() As
                | short
                | 
                |     Returns or sets the RelationsUpdateInPartContextSynchronousRelations
                |     parameter.
                |     Role:Return or Set the RelationsUpdateInPartContextSynchronousRelations
                |     parameter if it is possible in the current administrative context. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         oRelationsUpdateInPartContextSynchronousRelations
                |             Legal values:
                |             0 : creation of unsynchronous relations
                |             1 : creation of synchronous relations.

        :return: int
        :rtype: int
        """

        return self.knowledge_sheet_setting_att.RelationsUpdateInPartContextSynchronousRelations

    @relations_update_in_part_context_synchronous_relations.setter
    def relations_update_in_part_context_synchronous_relations(self, value: int):
        """
        :param int value:
        """

        self.knowledge_sheet_setting_att.RelationsUpdateInPartContextSynchronousRelations = value

    def get_design_tables_copy_data_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetDesignTablesCopyDataInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the DesignTablesCopyData
                |     parameter.
                |     Role:Retrieves the state of the DesignTablesCopyData parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.knowledge_sheet_setting_att.GetDesignTablesCopyDataInfo(io_admin_level, io_locked)

    def get_design_tables_synchronization_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetDesignTablesSynchronizationInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the DesignTablesSynchronization
                |     parameter.
                |     Role:Retrieves the state of the DesignTablesSynchronization parameter in
                |     the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.knowledge_sheet_setting_att.GetDesignTablesSynchronizationInfo(io_admin_level, io_locked)

    def get_parameter_name_surrounded_by_the_symbol_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetParameterNameSurroundedByTheSymbolInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the
                |     ParameterNameSurroundedByTheSymbol parameter.
                |     Role:Retrieves the state of the ParameterNameSurroundedByTheSymbol
                |     parameter in the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.knowledge_sheet_setting_att.GetParameterNameSurroundedByTheSymbolInfo(io_admin_level, io_locked)

    def get_parameter_tree_view_with_formula_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetParameterTreeViewWithFormulaInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ParameterTreeViewWithFormula
                |     parameter.
                |     Role:Retrieves the state of the ParameterTreeViewWithFormula parameter in
                |     the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.knowledge_sheet_setting_att.GetParameterTreeViewWithFormulaInfo(io_admin_level, io_locked)

    def get_parameter_tree_view_with_value_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetParameterTreeViewWithValueInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ParameterTreeViewWithValue
                |     parameter.
                |     Role:Retrieves the state of the ParameterTreeViewWithValue parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.knowledge_sheet_setting_att.GetParameterTreeViewWithValueInfo(io_admin_level, io_locked)

    def get_relations_update_in_part_context_evaluate_during_update_info(self,
                                                                         io_admin_level: str,
                                                                         io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetRelationsUpdateInPartContextEvaluateDuringUpdateInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the
                |     RelationsUpdateInPartContextEvaluateDuringUpdate
                |     parameter.
                |     Role:Retrieves the state of the
                |     RelationsUpdateInPartContextEvaluateDuringUpdate parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.knowledge_sheet_setting_att.GetRelationsUpdateInPartContextEvaluateDuringUpdateInfo(io_admin_level,
                                                                                                        io_locked)

    def get_relations_update_in_part_context_synchronous_relations_info(self,
                                                                        io_admin_level: str,
                                                                        io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetRelationsUpdateInPartContextSynchronousRelationsInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the
                |     RelationsUpdateInPartContextSynchronousRelations
                |     parameter.
                |     Role:Retrieves the state of the
                |     RelationsUpdateInPartContextSynchronousRelations parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.knowledge_sheet_setting_att.GetRelationsUpdateInPartContextSynchronousRelationsInfo(io_admin_level,
                                                                                                        io_locked)

    def set_design_tables_copy_data_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetDesignTablesCopyDataLock(boolean iLocked)
                | 
                |     Locks or unlocks the DesignTablesCopyData parameter.
                |     Role:Locks or unlocks the DesignTablesCopyData parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.knowledge_sheet_setting_att.SetDesignTablesCopyDataLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_design_tables_copy_data_lock'
        # # vba_code = """
        # # Public Function set_design_tables_copy_data_lock(knowledge_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     knowledge_sheet_setting_att.SetDesignTablesCopyDataLock iLocked
        # #     set_design_tables_copy_data_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_design_tables_synchronization_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetDesignTablesSynchronizationLock(boolean iLocked)
                | 
                |     Locks or unlocks the DesignTablesSynchronization
                |     parameter.
                |     Role:Locks or unlocks the DesignTablesSynchronization parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.knowledge_sheet_setting_att.SetDesignTablesSynchronizationLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_design_tables_synchronization_lock'
        # # vba_code = """
        # # Public Function set_design_tables_synchronization_lock(knowledge_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     knowledge_sheet_setting_att.SetDesignTablesSynchronizationLock iLocked
        # #     set_design_tables_synchronization_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_parameter_name_surrounded_by_the_symbol_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetParameterNameSurroundedByTheSymbolLock(boolean
                | iLocked)
                | 
                |     Locks or unlocks the ParameterNameSurroundedByTheSymbol
                |     parameter.
                |     Role:Locks or unlocks the ParameterNameSurroundedByTheSymbol parameter if
                |     it is possible in the current administrative context. In user mode this method
                |     will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.knowledge_sheet_setting_att.SetParameterNameSurroundedByTheSymbolLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_parameter_name_surrounded_by_the_symbol_lock'
        # # vba_code = """
        # # Public Function set_parameter_name_surrounded_by_the_symbol_lock(knowledge_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     knowledge_sheet_setting_att.SetParameterNameSurroundedByTheSymbolLock iLocked
        # #     set_parameter_name_surrounded_by_the_symbol_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_parameter_tree_view_with_formula_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetParameterTreeViewWithFormulaLock(boolean iLocked)
                | 
                |     Locks or unlocks the ParameterTreeViewWithFormula
                |     parameter.
                |     Role:Locks or unlocks the ParameterTreeViewWithFormula parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.knowledge_sheet_setting_att.SetParameterTreeViewWithFormulaLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_parameter_tree_view_with_formula_lock'
        # # vba_code = """
        # # Public Function set_parameter_tree_view_with_formula_lock(knowledge_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     knowledge_sheet_setting_att.SetParameterTreeViewWithFormulaLock iLocked
        # #     set_parameter_tree_view_with_formula_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_parameter_tree_view_with_value_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetParameterTreeViewWithValueLock(boolean iLocked)
                | 
                |     Locks or unlocks the ParameterTreeViewWithValue parameter.
                |     Role:Locks or unlocks the ParameterTreeViewWithValue parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.knowledge_sheet_setting_att.SetParameterTreeViewWithValueLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_parameter_tree_view_with_value_lock'
        # # vba_code = """
        # # Public Function set_parameter_tree_view_with_value_lock(knowledge_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     knowledge_sheet_setting_att.SetParameterTreeViewWithValueLock iLocked
        # #     set_parameter_tree_view_with_value_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_relations_update_in_part_context_evaluate_during_update_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetRelationsUpdateInPartContextEvaluateDuringUpdateLock(boolean
                | iLocked)
                | 
                |     Locks or unlocks the RelationsUpdateInPartContextEvaluateDuringUpdate
                |     parameter.
                |     Role:Locks or unlocks the RelationsUpdateInPartContextEvaluateDuringUpdate
                |     parameter if it is possible in the current administrative context. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.knowledge_sheet_setting_att.SetRelationsUpdateInPartContextEvaluateDuringUpdateLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_relations_update_in_part_context_evaluate_during_update_lock'
        # # vba_code = """
        # # Public Function set_rels_update_in_part_context_evaluate_during_update_lock(knowledge_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     knowledge_sheet_setting_att.SetRelationsUpdateInPartContextEvaluateDuringUpdateLock iLocked
        # #     set_relations_update_in_part_context_evaluate_during_update_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_relations_update_in_part_context_synchronous_relations_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetRelationsUpdateInPartContextSynchronousRelationsLock(boolean
                | iLocked)
                | 
                |     Locks or unlocks the RelationsUpdateInPartContextSynchronousRelations
                |     parameter.
                |     Role:Locks or unlocks the RelationsUpdateInPartContextSynchronousRelations
                |     parameter if it is possible in the current administrative context. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        """
        return self.knowledge_sheet_setting_att.SetRelationsUpdateInPartContextSynchronousRelationsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_relations_update_in_part_context_synchronous_relations_lock'
        # # vba_code = """
        # # Public Function set_relations_update_in_part_context_synchronous_relations_lock(knowledge_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     knowledge_sheet_setting_att.SetRelationsUpdateInPartContextSynchronousRelationsLock iLocked
        # #     set_relations_update_in_part_context_synchronous_relations_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'KnowledgeSheetSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pathlib import Path
from typing import Iterator

from pycatia.exception_handling.exceptions import CATIAApplicationException
from pycatia.drafting_interfaces.drawing_picture import DrawingPicture
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class DrawingPictures(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     DrawingPictures
                | 
                | A collection of all the drawing pictures currently managed by a drawing view of
                | drawing sheet in a drawing document.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=DrawingPicture)
        self.drawing_pictures = com_object

    def add(self, i_drawing_picture_path: Path, i_position_x: float, i_position_y: float) -> DrawingPicture:
        """

        When passing a path of the image file to this function it's recommended to use the absolute path or the method
        may not work. Otherwise, Path library will try and determine the absolute path if it can.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Add(CATBSTR iDrawingPicturePath,
                | double iPositionX,
                | double iPositionY) As DrawingPicture
                | 
                |     Inserts a drawing picture in the drawing view and adds it to the
                |     DrawingPictures collection.
                | 
                |     Parameters:
                | 
                |         iDrawingPicturePath
                |             The path of the picture file (ex : "C:/tmp/ball.bmp") .
                |         iPositionX,iPositionY
                |             The drawing picture x and y coordinates, expressed in millimeters,
                |             with respect to the drawing view coordinate system
                |             
                | 
                |     Returns:
                |         The inserted drawing picture 
                | 
                | Example:
                |     The following example inserts a drawing picture from a given picture file
                |     path The MyView is the active view in the active drawing
                |     sheet
                | 
                |      Dim MySheet As DrawingSheet
                |      Set MySheet = CATIA.ActiveDocument.Sheets.ActiveSheet
                |      Dim MyView As DrawingView
                |      Set MyView = MySheet.Views.ActiveView
                |      Dim MyDrawingPicture1 As DrawingPicture
                |      Set MyDrawingPicture1 = MyView.Pictures.Add("C:/tmp/ball.bmp", 100., 50.)

        :param Path i_drawing_picture_path:
        :param float i_position_x:
        :param float i_position_y:
        :return: DrawingPicture
        :rtype: DrawingPicture
        """

        absolute_path = i_drawing_picture_path.absolute()
        if not absolute_path.is_file():
            raise CATIAApplicationException(f'Could not find image file: "{absolute_path}".')
        return DrawingPicture(self.drawing_pictures.Add(absolute_path, i_position_x, i_position_y))

    def item(self, i_index: cat_variant) -> DrawingPicture:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(CATVariant iIndex) As DrawingPicture
                | 
                |     Returns a drawing picture using its index or its name from the
                |     DrawingPictures collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the drawing picture to retrieve from the
                |             collection of drawing pictures. As a numerics, this index is the rank of the
                |             drawing picture in the collection. The index of the first drawing picture in
                |             the collection is 1, and the index of the last drawing picture is Count. As a
                |             string, it is the name you assigned to the drawing picture using the
                |             
                | 
                |         AnyObject.Name property 
                |     Returns:
                |         The retrieved drawing picture 
                | 
                | Example:
                |     This example retrieves in ThisDrawingPicture the second drawing picture,
                |     MyView in the drawing view collection of the active sheet in the active
                |     document, supposed to be a drawing document.
                | 
                |      Dim MySheet As DrawingSheet
                |      Set MySheet = CATIA.ActiveDocument.Sheets.ActiveSheet
                |      Dim MyView  As DrawingView
                |      Set MyView  = MySheet.Views.ActiveView
                |      Dim ThisDrawingPicture As DrawingPicture
                |      Set ThisDrawingPicture = MyView.Pictures.Item(2)

        :param cat_variant i_index:
        :return: DrawingPicture
        :rtype: DrawingPicture
        """
        return DrawingPicture(self.drawing_pictures.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a drawing picture from the DrawingPictures
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the drawing picture to remove from the collection of
                |             drawing pictures. As a numerics, this index is the rank of the drawing picture
                |             in the collection. The index of the first drawing picture in the collection is
                |             1, and the index of the last drawing picture is Count. As a string, it is the
                |             name you assigned to the drawing picture using the
                |             
                | 
                |         AnyObject.Name property 
                | 
                | Example:
                |     The following example removes the third drawing picture in the drawing
                |     pictures collection of the active view of the active document, supposed to be a
                |     drawing document.
                | 
                |      Dim MyView As DrawingView
                |      Set MyView  = MySheet.Views.ActiveView
                |      MyView.Pictures.Remove(3)

        :param cat_variant i_index:
        :return: None
        :rtype: None
        """
        return self.drawing_pictures.Remove(i_index)

    def __getitem__(self, n: int) -> DrawingPicture:
        if (n + 1) > self.count:
            raise StopIteration

        return DrawingPicture(self.drawing_pictures.item(n + 1))

    def __iter__(self) -> Iterator[DrawingPicture]:
        for i in range(self.count):
            yield self.child_object(self.com_object.item(i + 1))

    def __repr__(self):
        return f'DrawingPictures(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class LanguageSheetSettingAtt(SettingController):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         LanguageSheetSettingAtt
                | 
                | The interface to access a CATIALanguageSheetSettingAtt.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.language_sheet_setting_att = com_object

    @property
    def knowledge_build_path_directory(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property KnowledgeBuildPathDirectory() As CATBSTR
                | 
                |     Returns or sets the CATKnowledgeBuildPath setting
                |     parameter.
                |     Role:Return or Set the CATKnowledgeBuildPath parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         oKnowledgeBuildPathDirectory
                |             The knowledge build path directory: the path where all the
                |             resources are located.

        :return: str
        :rtype: str
        """

        return self.language_sheet_setting_att.KnowledgeBuildPathDirectory

    @knowledge_build_path_directory.setter
    def knowledge_build_path_directory(self, value: str):
        """
        :param str value:
        """

        self.language_sheet_setting_att.KnowledgeBuildPathDirectory = value

    @property
    def list_of_packages_to_load(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ListOfPackagesToLoad() As CATBSTR
                | 
                |     Returns or sets the ListOfPackagesToLoad parameter.
                |     Role:Return or Set the ListOfPackagesToLoad parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         oListOfPackagesToLoad
                |             The list of packages to load.

        :return: str
        :rtype: str
        """

        return self.language_sheet_setting_att.ListOfPackagesToLoad

    @list_of_packages_to_load.setter
    def list_of_packages_to_load(self, value: str):
        """
        :param str value:
        """

        self.language_sheet_setting_att.ListOfPackagesToLoad = value

    @property
    def load_all_packages(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property LoadAllPackages() As short
                | 
                |     Returns or sets the LoadAllPackages parameter.
                |     Role:Return or Set the LoadAllPackages parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         oLoadAllPackages
                |             Legal values:
                |             0 : to not load all packages
                |             1 : to load all packages.

        :return: int
        :rtype: int
        """

        return self.language_sheet_setting_att.LoadAllPackages

    @load_all_packages.setter
    def load_all_packages(self, value: int):
        """
        :param int value:
        """

        self.language_sheet_setting_att.LoadAllPackages = value

    @property
    def load_extended_language_lib(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property LoadExtendedLanguageLib() As short
                | 
                |     Returns or sets the LoadExtendedLanguageLib parameter.
                |     Role:Return or Set the LoadExtendedLanguageLib parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         oLoadExtendedLanguageLib
                |             Legal values:
                |             0 : to not use extended libraries
                |             1 : to use extended libraries.

        :return: int
        :rtype: int
        """

        return self.language_sheet_setting_att.LoadExtendedLanguageLib

    @load_extended_language_lib.setter
    def load_extended_language_lib(self, value: int):
        """
        :param int value:
        """

        self.language_sheet_setting_att.LoadExtendedLanguageLib = value

    @property
    def reference_directory_for_types(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ReferenceDirectoryForTypes() As CATBSTR
                | 
                |     Returns or sets the ReferenceDirectoryForTypes parameter.
                |     Role:Return or Set the ReferenceDirectoryForTypes parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         oReferenceDirectoryForTypes
                |             The reference directory for types.

        :return: str
        :rtype: str
        """

        return self.language_sheet_setting_att.ReferenceDirectoryForTypes

    @reference_directory_for_types.setter
    def reference_directory_for_types(self, value: str):
        """
        :param str value:
        """

        self.language_sheet_setting_att.ReferenceDirectoryForTypes = value

    def get_knowledge_build_path_directory_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetKnowledgeBuildPathDirectoryInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the CATKnowledgeBuildPath setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.language_sheet_setting_att.GetKnowledgeBuildPathDirectoryInfo(io_admin_level, io_locked)

    def get_list_of_packages_to_load_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetListOfPackagesToLoadInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the ListOfPackagesToLoad setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.language_sheet_setting_att.GetListOfPackagesToLoadInfo(io_admin_level, io_locked)

    def get_load_all_packages_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetLoadAllPackagesInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the LoadAllPackages setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.language_sheet_setting_att.GetLoadAllPackagesInfo(io_admin_level, io_locked)

    def get_load_extended_language_lib_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetLoadExtendedLanguageLibInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the LoadExtendedLanguageLib setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.language_sheet_setting_att.GetLoadExtendedLanguageLibInfo(io_admin_level, io_locked)

    def get_reference_directory_for_types_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetReferenceDirectoryForTypesInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the ReferenceDirectoryForTypes setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.language_sheet_setting_att.GetReferenceDirectoryForTypesInfo(io_admin_level, io_locked)

    def set_knowledge_build_path_directory_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetKnowledgeBuildPathDirectoryLock(boolean iLocked)
                | 
                |     Locks or unlocks the CATKnowledgeBuildPath setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.language_sheet_setting_att.SetKnowledgeBuildPathDirectoryLock(i_locked)

    def set_list_of_packages_to_load_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetListOfPackagesToLoadLock(boolean iLocked)
                | 
                |     Locks or unlocks the ListOfPackagesToLoad setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.language_sheet_setting_att.SetListOfPackagesToLoadLock(i_locked)

    def set_load_all_packages_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetLoadAllPackagesLock(boolean iLocked)
                | 
                |     Locks or unlocks the LoadAllPackages setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.language_sheet_setting_att.SetLoadAllPackagesLock(i_locked)

    def set_load_extended_language_lib_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetLoadExtendedLanguageLibLock(boolean iLocked)
                | 
                |     Locks or unlocks the LoadExtendedLanguageLib setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.language_sheet_setting_att.SetLoadExtendedLanguageLibLock(i_locked)

    def set_reference_directory_for_types_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetReferenceDirectoryForTypesLock(boolean iLocked)
                | 
                |     Locks or unlocks the ReferenceDirectoryForTypes setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.language_sheet_setting_att.SetReferenceDirectoryForTypesLock(i_locked)

    def __repr__(self):
        return f'LanguageSheetSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeAssemble(HybridShape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeAssemble
                | 
                | Represents the hybrid shape assemble feature object.
                | Role: To access the data of the hybrid shape assemble feature object. This data
                | includes:
                | 
                |     A list of the assembled elements
                |     Some methods to access this data
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapeAssemble
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_assemble = com_object

    @property
    def invert(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Invert() As boolean
                | 
                |     Returns or sets the invert mode.
                |     Legal values: True the result is inverted. False the result is not
                |     inverted.
                | 
                |     Example:
                | 
                |           This example sets the invert mode of
                |          the HybShpAssemble hybrid shape assemble feature to
                |          True.
                |          
                | 
                |          HybShpAssemble.Invert = True

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_assemble.Invert

    @invert.setter
    def invert(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_assemble.Invert = value

    def add_element(self, i_element: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddElement(Reference iElement)
                | 
                |     Adds an element to the hybrid shape assemble feature
                |     object.
                | 
                |     Parameters:
                | 
                |         iElement
                |             The element to add to the hybrid shape assemble feature
                |             object.
                |             Sub-element(s) supported (see 
                | 
                |         Boundary object): Face, TriDimFeatEdge and BiDimFeatEdge.
                |         
                | 
                | Examples:
                |     The following example adds the iElement feature object to the
                |     HybridShapeAssemble object.
                | 
                |      HybridShapeAssemble.AddElement iElement

        :param Reference i_element:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_assemble.AddElement(i_element.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_element'
        # # vba_code = """
        # # Public Function add_element(hybrid_shape_assemble)
        # #     Dim iElement (2)
        # #     hybrid_shape_assemble.AddElement iElement
        # #     add_element = iElement
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_sub_element(self, i_sub_element: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddSubElement(Reference iSubElement)
                | 
                |     Adds a sub element to the hybrid shape assemble feature
                |     object.
                | 
                |     Parameters:
                | 
                |         iSubElement
                |             The sub element to remove to the hybrid shape assemble feature
                |             object.

        :param Reference i_sub_element:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_assemble.AddSubElement(i_sub_element.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_sub_element'
        # # vba_code = """
        # # Public Function add_sub_element(hybrid_shape_assemble)
        # #     Dim iSubElement (2)
        # #     hybrid_shape_assemble.AddSubElement iSubElement
        # #     add_sub_element = iSubElement
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def append_federated_element(self, i_element: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AppendFederatedElement(Reference iElement)
                | 
                |     Appends an init to the list of elements to federate.
                | 
                |     Parameters:
                | 
                |         iElement
                |             Element to append. 
                | 
                |     See also:
                |         Reference

        :param Reference i_element:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_assemble.AppendFederatedElement(i_element.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'append_federated_element'
        # # vba_code = """
        # # Public Function append_federated_element(hybrid_shape_assemble)
        # #     Dim iElement (2)
        # #     hybrid_shape_assemble.AppendFederatedElement iElement
        # #     append_federated_element = iElement
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_angular_tolerance(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetAngularTolerance() As double
                | 
                |     Get the angular tolerance.
                | 
                |     Parameters:
                | 
                |         oValue
                |             The angular tolerance.

        :return: float
        :rtype: float
        """
        return self.hybrid_shape_assemble.GetAngularTolerance()

    def get_angular_tolerance_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetAngularToleranceMode() As boolean
                | 
                |     Get the angular tolerance mode.
                | 
                |     Parameters:
                | 
                |         oValue
                |             The angular tolerance mode.

        :return: bool
        :rtype: bool
        """
        return self.hybrid_shape_assemble.GetAngularToleranceMode()

    def get_connex(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetConnex() As boolean
                | 
                |     Get the connex checker flag.
                | 
                |     Parameters:
                | 
                |         oConnex

        :return: bool
        :rtype: bool
        """
        return self.hybrid_shape_assemble.GetConnex()

    def get_deviation(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetDeviation() As double
                | 
                |     Get the deviation value.
                | 
                |     Parameters:
                | 
                |         odeviation
                |             The deviation.

        :return: float
        :rtype: float
        """
        return self.hybrid_shape_assemble.GetDeviation()

    def get_element(self, i_rank: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetElement(long iRank) As Reference
                | 
                |     Retrieves an element used by the hybrid shape assemble feature
                |     object.
                | 
                |     Parameters:
                | 
                |         iRank
                |             The rank of the element to read. 
                | 
                |     Examples:
                |         The following example gets the oElement feature object of the
                |         HybridShapeAssemble object at the position iRank.
                | 
                |          Dim oElement As Reference
                |          Set oElement = HybridShapeAssemble.GetElement (iRank).

        :param int i_rank:
        :return: Reference
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_assemble.GetElement(i_rank))

    def get_elements_size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetElementsSize() As long
                | 
                |     Returns the size of the list of elements to assemble in the hybrid shape
                |     assemble feature object.
                | 
                |     Parameters:
                | 
                |         oSize
                |             Number of elements in the Assemble.
                | 
                |             Example:
                |                 This example retrieves the number of elements in the
                |                 HybShpAssemble hybrid shape assemble.
                | 
                |                  Dim oSize As  long
                |                  oSize = HybShpAssemble.GetElementsSize

        :return: int
        :rtype: int
        """
        return self.hybrid_shape_assemble.GetElementsSize()

    def get_federated_element(self, i_rank: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetFederatedElement(long iRank) As Reference
                | 
                |     Retrieves an federated inits used by the hybrid shape assemble feature
                |     object.
                | 
                |     Parameters:
                | 
                |         iRank
                |             The rank of the element to read. 
                |         oElement
                |             The federated element. 
                | 
                |     See also:
                |         Reference

        :param int i_rank:
        :return: Reference
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_assemble.GetFederatedElement(i_rank))

    def get_federated_elements_size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetFederatedElementsSize() As long
                | 
                |     Gets the number of federated inits.
                | 
                |     Parameters:
                | 
                |         Size
                |             Number of elements.

        :return: int
        :rtype: int
        """
        return self.hybrid_shape_assemble.GetFederatedElementsSize()

    def get_federation_propagation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetFederationPropagation() As long
                | 
                |     Gets the propagation mode of the federation.
                | 
                |     Parameters:
                | 
                |         i
                |             type of propagation (0: No, 1: All, 2: Continuity,
                |             3:Tangency).

        :return: int
        :rtype: int
        """
        return self.hybrid_shape_assemble.GetFederationPropagation()

    def get_manifold(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetManifold() As boolean
                | 
                |     Get the manifold checker flag.
                | 
                |     Parameters:
                | 
                |         oManifold

        :return: bool
        :rtype: bool
        """
        return self.hybrid_shape_assemble.GetManifold()

    def get_simplify(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetSimplify() As boolean
                | 
                |     Get the simplify flag.
                | 
                |     Parameters:
                | 
                |         oSimplify

        :return: bool
        :rtype: bool
        """
        return self.hybrid_shape_assemble.GetSimplify()

    def get_sub_element(self, i_rank: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetSubElement(long iRank) As Reference
                | 
                |     Retrieves a sub element used by the hybrid shape assemble feature
                |     object.
                | 
                |     Parameters:
                | 
                |         iRank
                |             The rank of the subelement to read.

        :param int i_rank:
        :return: Reference
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_assemble.GetSubElement(i_rank))

    def get_sub_elements_size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetSubElementsSize() As long
                | 
                |     Returns the size of the list of sub-elements to remove in the hybrid shape
                |     assemble feature object.
                | 
                |     Parameters:
                | 
                |         oSize
                |             Number of sub elements in the Assemble.
                | 
                |             Example:
                |                 This example retrieves the number of sub elements in the
                |                 HybShpAssemble hybrid shape assemble.
                | 
                |                  Dim oSize As  long
                |                  oSize = HybShpAssemble.GetSubElementsSize

        :return: int
        :rtype: int
        """
        return self.hybrid_shape_assemble.GetSubElementsSize()

    def get_suppress_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetSuppressMode() As boolean
                | 
                |     Get the SuppressMode flag.
                | 
                |     Parameters:
                | 
                |         oSuppressMode

        :return: bool
        :rtype: bool
        """
        return self.hybrid_shape_assemble.GetSuppressMode()

    def get_tangency_continuity(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetTangencyContinuity() As boolean
                | 
                |     Get the tangency continuity checker flag.
                | 
                |     Parameters:
                | 
                |         oTangencyContinuity

        :return: bool
        :rtype: bool
        """
        return self.hybrid_shape_assemble.GetTangencyContinuity()

    def remove_element(self, i_rank: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveElement(long iRank)
                | 
                |     Removes an element used by the hybrid shape assemble feature
                |     object.
                | 
                |     Parameters:
                | 
                |         iRank
                |             The rank of the element to remove. 
                | 
                |     Examples:
                |         The following example removes the feature object from the
                |         HybridShapeAssemble object at the position iRank.
                | 
                |          HybridShapeAssemble.RemoveElement iRank.

        :param int i_rank:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_assemble.RemoveElement(i_rank)

    def remove_federated_element(self, i_rank: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveFederatedElement(long iRank)
                | 
                |     Removes an element to the list of elements to federate.
                | 
                |     Parameters:
                | 
                |         iRank
                |             Position of the element to remove.

        :param int i_rank:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_assemble.RemoveFederatedElement(i_rank)

    def remove_sub_element(self, i_rank: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveSubElement(long iRank)
                | 
                |     Removes a sub element used by the hybrid shape assemble feature
                |     object.
                | 
                |     Parameters:
                | 
                |         iRank
                |             The rank of the element to remove.

        :param int i_rank:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_assemble.RemoveSubElement(i_rank)

    def replace_element(self, i_pos: int, i_element: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ReplaceElement(long iPos,
                | Reference iElement)
                | 
                |     Replaces the element at specified position in the hybrid shape assemble
                |     feature object.
                | 
                |     Parameters:
                | 
                |         iPos
                |             Position at which the element should be replaced. 
                |         iElement
                |             Reference of the element to be inserted.
                | 
                |             Example:
                |                 This example replaces the element in the HybShpAssemble
                |                 assemble feature at specified position iPos
                | 
                |                  HybShpAssemble.ReplaceElement iPos,iElement

        :param int i_pos:
        :param Reference i_element:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_assemble.ReplaceElement(i_pos, i_element.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'replace_element'
        # # vba_code = """
        # # Public Function replace_element(hybrid_shape_assemble)
        # #     Dim iPos (2)
        # #     hybrid_shape_assemble.ReplaceElement iPos
        # #     replace_element = iPos
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_angular_tolerance(self, i_value: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetAngularTolerance(double iValue)
                | 
                |     Set the angular tolerance.
                | 
                |     Parameters:
                | 
                |         iValue
                |             The angular tolerance.

        :param float i_value:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_assemble.SetAngularTolerance(i_value)

    def set_angular_tolerance_mode(self, i_value: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetAngularToleranceMode(boolean iValue)
                | 
                |     Set the angular tolerance mode.
                | 
                |     Parameters:
                | 
                |         iValue
                |             The angular tolerance mode.

        :param bool i_value:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_assemble.SetAngularToleranceMode(i_value)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_angular_tolerance_mode'
        # # vba_code = """
        # # Public Function set_angular_tolerance_mode(hybrid_shape_assemble)
        # #     Dim iValue (2)
        # #     hybrid_shape_assemble.SetAngularToleranceMode iValue
        # #     set_angular_tolerance_mode = iValue
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_connex(self, i_connex: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetConnex(boolean iConnex)
                | 
                |     Set the connex checker flag.
                | 
                |     Parameters:
                | 
                |         iConnex

        :param bool i_connex:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_assemble.SetConnex(i_connex)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_connex'
        # # vba_code = """
        # # Public Function set_connex(hybrid_shape_assemble)
        # #     Dim iConnex (2)
        # #     hybrid_shape_assemble.SetConnex iConnex
        # #     set_connex = iConnex
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_deviation(self, ideviation: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetDeviation(double ideviation)
                | 
                |     Set the deviation value.
                | 
                |     Parameters:
                | 
                |         ideviation
                |             The deviation.

        :param float ideviation:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_assemble.SetDeviation(ideviation)

    def set_federation_propagation(self, i_mode: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetFederationPropagation(long iMode)
                | 
                |     Sets the propagation mode of federation.
                | 
                |     Parameters:
                | 
                |         i
                |             type of propagation (0: No, 1: All, 2: Continuity,
                |             3:Tangency).

        :param int i_mode:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_assemble.SetFederationPropagation(i_mode)

    def set_manifold(self, i_manifold: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetManifold(boolean iManifold)
                | 
                |     Set the manifold checker flag.
                | 
                |     Parameters:
                | 
                |         iManifold

        :param bool i_manifold:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_assemble.SetManifold(i_manifold)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_manifold'
        # # vba_code = """
        # # Public Function set_manifold(hybrid_shape_assemble)
        # #     Dim iManifold (2)
        # #     hybrid_shape_assemble.SetManifold iManifold
        # #     set_manifold = iManifold
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_simplify(self, i_simplify: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetSimplify(boolean iSimplify)
                | 
                |     Set the simplify flag.
                | 
                |     Parameters:
                | 
                |         iSimplify

        :param bool i_simplify:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_assemble.SetSimplify(i_simplify)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_simplify'
        # # vba_code = """
        # # Public Function set_simplify(hybrid_shape_assemble)
        # #     Dim iSimplify (2)
        # #     hybrid_shape_assemble.SetSimplify iSimplify
        # #     set_simplify = iSimplify
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_suppress_mode(self, i_suppress_mode: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetSuppressMode(boolean iSuppressMode)
                | 
                |     Set the SuppressMode flag.
                | 
                |     Parameters:
                | 
                |         iSuppressMode

        :param bool i_suppress_mode:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_assemble.SetSuppressMode(i_suppress_mode)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_suppress_mode'
        # # vba_code = """
        # # Public Function set_suppress_mode(hybrid_shape_assemble)
        # #     Dim iSuppressMode (2)
        # #     hybrid_shape_assemble.SetSuppressMode iSuppressMode
        # #     set_suppress_mode = iSuppressMode
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_tangency_continuity(self, i_tangency_continuity: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetTangencyContinuity(boolean iTangencyContinuity)
                | 
                |     Set the tangency continuity checker flag.
                | 
                |     Parameters:
                | 
                |         iTangencyContinuity

        :param bool i_tangency_continuity:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_assemble.SetTangencyContinuity(i_tangency_continuity)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_tangency_continuity'
        # # vba_code = """
        # # Public Function set_tangency_continuity(hybrid_shape_assemble)
        # #     Dim iTangencyContinuity (2)
        # #     hybrid_shape_assemble.SetTangencyContinuity iTangencyContinuity
        # #     set_tangency_continuity = iTangencyContinuity
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'HybridShapeAssemble(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.mec_mod_interfaces.factory import Factory
from pycatia.tps_interfaces.capture import Capture


class CaptureFactory(Factory):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Factory
                |                         CaptureFactory
                | 
                | Interface for the Capture Factory.
                | This factory is implemented on the Set object. All the created Captures are
                | added to the Set from which this interface is retrieved.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.capture_factory = com_object

    def create_capture(self) -> Capture:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateCapture() As Capture
                | 
                |     Create a Capture.
                | 
                |     Parameters:
                | 
                |         oCapture
                |             The new created Capture.

        :return: Capture
        :rtype: Capture
        """
        return Capture(self.capture_factory.CreateCapture())

    def __repr__(self):
        return f'CaptureFactory(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.sketcher_interfaces.curve_2D import Curve2D
from pycatia.sketcher_interfaces.point_2D import Point2D
from pycatia.system_interfaces.system_service import SystemService


class Spline2D(Curve2D):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SketcherInterfaces.GeometricElement
                |                         SketcherInterfaces.Geometry2D
                |                             SketcherInterfaces.Curve2D
                |                                 Spline2D
                | 
                | Class defining a spline in 2D Space.
                | A 2D spline is defined by its constituting control points.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.spline_2d = com_object

    def get_control_points(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetControlPoints(CATSafeArrayVariant oCtrlPoints)
                | 
                |     Returns the control points making up the spline.
                | 
                |     Parameters:
                | 
                |         oCtrlPoints
                |             The control points of the spline
                | 
                |             Example:
                |                 The following example fetches the list of control points
                |                 defining the
                |                 splinemySpline:
                | 
                |                  mySpline.GetControlPoints ControlPoints

        :return: tuple
        :rtype: tuple
        """

        vba_function_name = 'get_control_points'
        vba_code = """
        Public Function get_control_points(spline2_d)
            Dim oCtrlPoints (1)
            spline2_d.GetControlPoints oCtrlPoints
            get_control_points = oCtrlPoints
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_number_of_control_points(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetNumberOfControlPoints() As double
                | 
                |     Returns the number of Control Points of the Spline
                | 
                |     Parameters:
                | 
                |         oNumber
                |             The number of control points*

        :return: float
        :rtype: float
        """
        return self.spline_2d.GetNumberOfControlPoints()

    def insert_control_point_after(self, i_ctrl_point: Point2D, i_position: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub InsertControlPointAfter(Point2D iCtrlPoint,
                | long iPosition)
                | 
                |     Inserts control points in the spline. If a 2D point is given (and not a
                |     control
                |     point), a new control point is created and aggregated in the
                |     spline.
                | 
                |     Parameters:
                | 
                |         iCtrlPoint
                |             The new point to be inserted. (@see CATIAPoint2D and
                |             CATIAControlPoint2D
                |             for more information). 
                |         iPosition
                |             The position at which to insert the point.
                |             To insert a new control point as the first element, set iPosition
                |             to 0.
                | 
                |             Example:
                |                 The following example inserts a control point myCtrlPoint as
                |                 the second
                |                 element of the spline mySpline:
                | 
                |                  call mySpline.InsertControlPointAfter (myCtrlPoint,
                |                  1)

        :param Point2D i_ctrl_point:
        :param int i_position:
        :return: None
        :rtype: None
        """
        return self.spline_2d.InsertControlPointAfter(i_ctrl_point.com_object, i_position)

    def __repr__(self):
        return f'Spline2D(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class UnitsSheetSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         UnitsSheetSettingAtt
                | 
                | The interface to access a CATIAUnitsSheetSettingAtt.
                | This interface may be used to read or modify in the CATIA/Tools/Option the
                | settings values of Units sheet.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.units_sheet_setting_att = com_object

    @property
    def display_trailing_zeros(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property DisplayTrailingZeros() As short
                | 
                |     Returns or sets the DisplayTrailingZeros parameter.
                |     Role:Return or Set the DisplayTrailingZeros parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         oDisplayTrailingZeros
                |             Legal values:
                |             0 : to not display trailing zeros
                |             1 : to display trailing zeros.

        :return: int
        :rtype: int
        """

        return self.units_sheet_setting_att.DisplayTrailingZeros

    @display_trailing_zeros.setter
    def display_trailing_zeros(self, value: int):
        """
        :param int value:
        """

        self.units_sheet_setting_att.DisplayTrailingZeros = value

    @property
    def exp_notation_values_greater(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ExpNotationValuesGreater() As double
                | 
                |     Returns or sets the ExpNotationValuesGreater parameter.
                |     Role:Return or Set the ExpNotationValuesGreater parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         oExpNotationValuesGreater
                |             The minimum value for exponential notation values.

        :return: float
        :rtype: float
        """

        return self.units_sheet_setting_att.ExpNotationValuesGreater

    @exp_notation_values_greater.setter
    def exp_notation_values_greater(self, value: float):
        """
        :param float value:
        """

        self.units_sheet_setting_att.ExpNotationValuesGreater = value

    @property
    def exp_notation_values_lower(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ExpNotationValuesLower() As double
                | 
                |     Returns or sets the ExpNotationValuesLower parameter.
                |     Role:Return or Set the ExpNotationValuesGreater parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         oExpNotationValuesLower
                |             The maximum value for exponential notation values.

        :return: float
        :rtype: float
        """

        return self.units_sheet_setting_att.ExpNotationValuesLower

    @exp_notation_values_lower.setter
    def exp_notation_values_lower(self, value: float):
        """
        :param float value:
        """

        self.units_sheet_setting_att.ExpNotationValuesLower = value

    @property
    def list_of_magnitudes(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ListOfMagnitudes() As CATSafeArrayVariant (Read
                | Only)
                | 
                |     Returns or sets the ListOfMagnitudes parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: tuple
        :rtype: tuple
        """

        return self.units_sheet_setting_att.ListOfMagnitudes

    @property
    def list_of_magnitudes_size(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ListOfMagnitudesSize() As double (Read Only)
                | 
                |     Returns or sets the ListOfMagnitudesSize parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :return: float
        :rtype: float
        """

        return self.units_sheet_setting_att.ListOfMagnitudesSize

    @property
    def same_display(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property SameDisplay() As short
                | 
                |     Returns or sets the SameDisplay parameter.
                |     Role:Return or Set the SameDisplay parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         oSameDisplay
                |             Legal values:
                |             0 : to not display same display
                |             1 : to display same display.

        :return: int
        :rtype: int
        """

        return self.units_sheet_setting_att.SameDisplay

    @same_display.setter
    def same_display(self, value: int):
        """
        :param int value:
        """

        self.units_sheet_setting_att.SameDisplay = value

    def commit_for_units(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub CommitForUnits()
                | 
                |     Implements a function from an interface.
                | 
                |     See also:
                |         UnitsSheetSettingAtt.CommitForUnits

        :return: None
        :rtype: None
        """
        return self.units_sheet_setting_att.CommitForUnits()

    def get_decimal_read_only(self, i_magnitude_name: str, o_decimal_place_read_only: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetDecimalReadOnly(CATBSTR iMagnitudeName,
                | double oDecimalPlaceReadOnly)
                | 
                |     Returns the number of decimals for ReadOnly number.

        :param str i_magnitude_name:
        :param float o_decimal_place_read_only:
        :return: None
        :rtype: None
        """
        return self.units_sheet_setting_att.GetDecimalReadOnly(i_magnitude_name, o_decimal_place_read_only)

    def get_decimal_read_write(self, i_magnitude_name: str, o_decimal_place_read_write: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetDecimalReadWrite(CATBSTR iMagnitudeName,
                | double oDecimalPlaceReadWrite)
                | 
                |     Returns the number of decimals for ReadWrite number.

        :param str i_magnitude_name:
        :param float o_decimal_place_read_write:
        :return: None
        :rtype: None
        """
        return self.units_sheet_setting_att.GetDecimalReadWrite(i_magnitude_name, o_decimal_place_read_write)

    def get_dimensions_display_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetDimensionsDisplayInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the DimensionsDisplay setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.units_sheet_setting_att.GetDimensionsDisplayInfo(io_admin_level, io_locked)

    def get_display_trailing_zeros_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetDisplayTrailingZerosInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the DisplayTrailingZeros
                |     parameter.
                |     Role:Retrieves the state of the DisplayTrailingZeros parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.units_sheet_setting_att.GetDisplayTrailingZerosInfo(io_admin_level, io_locked)

    def get_exp_notation_values_greater_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetExpNotationValuesGreaterInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ExpNotationValuesGreater
                |     parameter.
                |     Role:Retrieves the state of the ExpNotationValuesGreater parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.units_sheet_setting_att.GetExpNotationValuesGreaterInfo(io_admin_level, io_locked)

    def get_exp_notation_values_lower_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetExpNotationValuesLowerInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ExpNotationValuesLower
                |     parameter.
                |     Role:Retrieves the state of the ExpNotationValuesLower parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.units_sheet_setting_att.GetExpNotationValuesLowerInfo(io_admin_level, io_locked)

    def get_list_of_magnitudes_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetListOfMagnitudesInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the ListOfMagnitudes setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.units_sheet_setting_att.GetListOfMagnitudesInfo(io_admin_level, io_locked)

    def get_magnitude_values(self,
                             i_magnitude_name: str,
                             o_unit_name: str,
                             o_decimal_place_read_write: float,
                             o_decimal_place_read_only: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetMagnitudeValues(CATBSTR iMagnitudeName,
                | CATBSTR oUnitName,
                | double oDecimalPlaceReadWrite,
                | double oDecimalPlaceReadOnly)
                | 
                |     Returns the Magnitude parameters.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :param str i_magnitude_name:
        :param str o_unit_name:
        :param float o_decimal_place_read_write:
        :param float o_decimal_place_read_only:
        :return: None
        :rtype: None
        """
        return self.units_sheet_setting_att.GetMagnitudeValues(i_magnitude_name, o_unit_name,
                                                               o_decimal_place_read_write, o_decimal_place_read_only)

    def get_same_display_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetSameDisplayInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the SameDisplay
                |     parameter.
                |     Role:Retrieves the state of the SameDisplay parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.units_sheet_setting_att.GetSameDisplayInfo(io_admin_level, io_locked)

    def reset_to_admin_values_for_units(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub ResetToAdminValuesForUnits()
                | 
                |     Implements a function from an interface.
                | 
                |     See also:
                |         UnitsSheetSettingAtt.ResetToAdminValuesForUnits

        :return: None
        :rtype: None
        """
        return self.units_sheet_setting_att.ResetToAdminValuesForUnits()

    def rollback_for_units(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub RollbackForUnits()
                | 
                |     Implements a function from an interface.
                | 
                |     See also:
                |         UnitsSheetSettingAtt.RollbackForUnits

        :return: None
        :rtype: None
        """
        return self.units_sheet_setting_att.RollbackForUnits()

    def save_repository_for_units(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SaveRepositoryForUnits()
                | 
                |     Implements a function from an interface.
                | 
                |     See also:
                |         UnitsSheetSettingAtt.SaveRepositoryForUnits

        :return: None
        :rtype: None
        """
        return self.units_sheet_setting_att.SaveRepositoryForUnits()

    def set_dimensions_display_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetDimensionsDisplayLock(boolean iLocked)
                | 
                |     Locks or unlocks the DimensionsDisplay setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.units_sheet_setting_att.SetDimensionsDisplayLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_dimensions_display_lock'
        # # vba_code = """
        # # Public Function set_dimensions_display_lock(units_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     units_sheet_setting_att.SetDimensionsDisplayLock iLocked
        # #     set_dimensions_display_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_display_trailing_zeros_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetDisplayTrailingZerosLock(boolean iLocked)
                | 
                |     Deprecated:
                |         V5R15. Use SetDimensionsDisplayLock. Locks or unlocks the
                |         DisplayTrailingZeros parameter.
                |         Role:Locks or unlocks the DisplayTrailingZeros parameter if it is
                |         possible in the current administrative context. In user mode this method will
                |         always return E_FAIL. 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.units_sheet_setting_att.SetDisplayTrailingZerosLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_display_trailing_zeros_lock'
        # # vba_code = """
        # # Public Function set_display_trailing_zeros_lock(units_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     units_sheet_setting_att.SetDisplayTrailingZerosLock iLocked
        # #     set_display_trailing_zeros_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_exp_notation_values_greater_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetExpNotationValuesGreaterLock(boolean iLocked)
                | 
                |     Deprecated:
                |         V5R15. Use SetSameDisplayLock. Locks or unlocks the
                |         ExpNotationValuesGreater parameter.
                |         Role:Locks or unlocks the ExpNotationValuesGreater parameter if it is
                |         possible in the current administrative context. In user mode this method will
                |         always return E_FAIL. 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.units_sheet_setting_att.SetExpNotationValuesGreaterLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_exp_notation_values_greater_lock'
        # # vba_code = """
        # # Public Function set_exp_notation_values_greater_lock(units_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     units_sheet_setting_att.SetExpNotationValuesGreaterLock iLocked
        # #     set_exp_notation_values_greater_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_exp_notation_values_lower_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetExpNotationValuesLowerLock(boolean iLocked)
                | 
                |     Deprecated:
                |         V5R15. Use SetDimensionsDisplayLock. Locks or unlocks the
                |         ExpNotationValuesLower parameter.
                |         Role:Locks or unlocks the ExpNotationValuesLower parameter if it is
                |         possible in the current administrative context. In user mode this method will
                |         always return E_FAIL. 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.units_sheet_setting_att.SetExpNotationValuesLowerLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_exp_notation_values_lower_lock'
        # # vba_code = """
        # # Public Function set_exp_notation_values_lower_lock(units_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     units_sheet_setting_att.SetExpNotationValuesLowerLock iLocked
        # #     set_exp_notation_values_lower_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_list_of_magnitudes_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetListOfMagnitudesLock(boolean iLocked)
                | 
                |     Locks or unlocks the ListOfMagnitudes setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.units_sheet_setting_att.SetListOfMagnitudesLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_list_of_magnitudes_lock'
        # # vba_code = """
        # # Public Function set_list_of_magnitudes_lock(units_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     units_sheet_setting_att.SetListOfMagnitudesLock iLocked
        # #     set_list_of_magnitudes_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_magnitude_values(self,
                             i_magnitude_name: str,
                             i_unit_name: str,
                             i_decimal_place_read_write: float,
                             i_decimal_place_read_only: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetMagnitudeValues(CATBSTR iMagnitudeName,
                | CATBSTR iUnitName,
                | double iDecimalPlaceReadWrite,
                | double iDecimalPlaceReadOnly)
                | 
                |     Sets the Magnitude parameters.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :param str i_magnitude_name:
        :param str i_unit_name:
        :param float i_decimal_place_read_write:
        :param float i_decimal_place_read_only:
        :return: None
        :rtype: None
        """
        return self.units_sheet_setting_att.SetMagnitudeValues(i_magnitude_name, i_unit_name,
                                                               i_decimal_place_read_write, i_decimal_place_read_only)

    def set_same_display_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetSameDisplayLock(boolean iLocked)
                | 
                |     Deprecated:
                |         V5R15. Use SetDimensionsDisplayLock. Locks or unlocks the SameDisplay
                |         parameter.
                |         Role:Locks or unlocks the SameDisplay parameter if it is possible in
                |         the current administrative context. In user mode this method will always return
                |         E_FAIL. 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.units_sheet_setting_att.SetSameDisplayLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_same_display_lock'
        # # vba_code = """
        # # Public Function set_same_display_lock(units_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     units_sheet_setting_att.SetSameDisplayLock iLocked
        # #     set_same_display_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'UnitsSheetSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""

from pycatia.in_interfaces.reference import Reference
from pycatia.in_interfaces.workbench import Workbench
from pycatia.space_analyses_interfaces.clashes import Clashes
from pycatia.space_analyses_interfaces.distances import Distances
from pycatia.space_analyses_interfaces.inertias import Inertias
from pycatia.space_analyses_interfaces.measurable import Measurable
from pycatia.space_analyses_interfaces.sections import Sections


class SPAWorkbench(Workbench):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Workbench
                |                         SPAWorkbench
                |
                | The object to manage all Space Analysis objects.
                |
                | This version allows you to manage inertia data, clashes, distances and
                | sections.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.spa_workbench = com_object.GetWorkbench("SPAWorkbench")

    @property
    def clashes(self) -> Clashes:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Clashes() As Clashes (Read Only)
                | 
                |     Returns the Clashes collection.
                |
                |     WARNING: this method will be DEPRECATED in the next release. It is
                |     recommended to use the method GetTechnologicalObject("Clashes") on the root
                |     product, to retrieve the Clashes collection.
                |
                |     Example:
                |
                |              This example retrieves the Clashes collection of the active
                |              document.
                |
                |
                |             Dim TheSPAWorkbench As Workbench
                |             Set TheSPAWorkbench = CATIA.ActiveDocument.GetWorkbench ( "SPAWorkbench" )
                |             Dim TheClashesList As Clashes
                |             Set TheClashesList = TheSPAWorkbench.Clashes

        :return: Clashes
        :rtype: Clashes
        """

        return Clashes(self.spa_workbench.Clashes)

    @property
    def distances(self) -> Distances:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Distances() As Distances (Read Only)
                | 
                |     Returns the Distances collection.
                |
                |     WARNING: this method will be DEPRECATED in the next release. It is
                |     recommended to use the method GetTechnologicalObject("Distances") on the root
                |     product, to retrieve the Distances collection.
                |
                |     Example:
                |
                |              This example retrieves the Distances collection of the active
                |              document.
                |
                |
                |             Dim TheSPAWorkbench As Workbench
                |             Set TheSPAWorkbench = CATIA.ActiveDocument.GetWorkbench ( "SPAWorkbench" )
                |             Dim TheDistancesList As Distances
                |             Set TheDistancesList = TheSPAWorkbench.Distances

        :return: Distances
        :rtype: Distances
        """

        return Distances(self.spa_workbench.Distances)

    @property
    def inertias(self) -> Inertias:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Inertias() As Inertias (Read Only)
                | 
                |     Returns the Inertias collection.
                |
                |     WARNING: this method will be DEPRECATED in the next release. It is
                |     recommended to use the method GetTechnologicalObject("Inertia") on the product
                |     to analyze, to retrieve an Inertia object.
                |
                |     Example:
                |
                |              This example retrieves the Inertias collection of the active
                |              document.
                |
                |
                |             Dim TheSPAWorkbench As Workbench
                |             Set TheSPAWorkbench = CATIA.ActiveDocument.GetWorkbench ( "SPAWorkbench" )
                |             Dim TheInertiasList As Inertias
                |             Set TheInertiasList = TheSPAWorkbench.Inertias

        :return: Inertias
        :rtype: Inertias
        """

        return Inertias(self.spa_workbench.Inertias)

    @property
    def sections(self) -> Sections:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Sections() As Sections (Read Only)
                | 
                |     Returns the Sections collection.
                |
                |     WARNING: this method will be DEPRECATED in the next release. It is
                |     recommended to use the method GetTechnologicalObject("Sections") on the root
                |     product, to retrieve the Sections collection.
                |
                |     Example:
                |
                |              This example retrieves the Sections collection of the active
                |              document.
                |
                |
                |             Dim TheSPAWorkbench As Workbench
                |             Set TheSPAWorkbench = CATIA.ActiveDocument.GetWorkbench ( "SPAWorkbench" )
                |             Dim TheSectionsList As Sections
                |             Set TheSectionsList = TheSPAWorkbench.Sections

        :return: Sections
        :rtype: Sections
        """

        return Sections(self.spa_workbench.Sections)

    def get_measurable(self, i_measured_item: Reference) -> Measurable:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetMeasurable(Reference iMeasuredItem) As Measurable
                | 
                |     Returns the Measurable object.
                |
                |     Example:
                |
                |              This example get the Measurable from the
                |              SPAWorkBench.
                |
                |
                |             Dim referenceObject As referenceObject
                |             Set referenceObject = "GetReference"
                |             Dim TheSPAWorkbench As Workbench
                |             Set TheSPAWorkbench = CATIA.ActiveDocument.GetWorkbench ( "SPAWorkbench" )
                |             Dim TheMeasurable As Measurable
                |             Set TheMeasurable = TheSPAWorkbench.GetMeasurable(referenceObject)

        :param Reference i_measured_item:
        :return: Measurable
        :rtype: Measurable
        """
        return Measurable(self.spa_workbench.GetMeasurable(i_measured_item.com_object))

    def __repr__(self):
        return f'SpaWorkbench(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.plane import Plane
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.length import Length
from pycatia.knowledge_interfaces.real_param import RealParam


class HybridShapePlaneEquation(Plane):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.Plane
                |                             HybridShapePlaneEquation
                | 
                | Plane define by an equation plane.
                | Role: Allows to access data of the plane feature created by its cartesian equation.
                | Plane equation is Ax+By+Cz = D.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_plane_equation = com_object

    @property
    def a(self) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property A() As RealParam (Read Only)
                | 
                |     Gets A coefficient for plane equation.
                | 
                |     Parameters:
                | 
                |         oA
                |             A Coefficient of cartesian plane 
                | 
                |     See also:
                |         RealParam 
                |     Returns:
                |         HRESULT S_OK if Ok E_FAIL else return error code for C++
                |         Implementations 
                |     See also:
                |         HybridShapeFactory

        :return: RealParam
        :rtype: RealParam
        """

        return RealParam(self.hybrid_shape_plane_equation.A)

    @property
    def b(self) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property B() As RealParam (Read Only)
                | 
                |     Gets B coefficient for plane equation.
                | 
                |     Parameters:
                | 
                |         oB
                |             B Coefficient of cartesian plane 
                | 
                |     See also:
                |         RealParam 
                |     Returns:
                |         HRESULT S_OK if Ok E_FAIL else return error code for C++
                |         Implementations 
                |     See also:
                |         HybridShapeFactory

        :return: RealParam
        :rtype: RealParam
        """

        return RealParam(self.hybrid_shape_plane_equation.B)

    @property
    def c(self) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property C() As RealParam (Read Only)
                | 
                |     Gets C coefficient for plane equation.
                | 
                |     Parameters:
                | 
                |         oC
                |             C Coefficient of cartesian plane return value for CATScript
                |             applications, with (IDLRETVAL) function type 
                | 
                |     See also:
                |         RealParam 
                |     Returns:
                |         HRESULT S_OK if Ok E_FAIL else return error code for C++
                |         Implementations 
                |     See also:
                |         HybridShapeFactory

        :return: RealParam
        :rtype: RealParam
        """

        return RealParam(self.hybrid_shape_plane_equation.C)

    @property
    def d(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property D() As Length (Read Only)
                | 
                |     Gets D coefficient for plane equation.
                | 
                |     Parameters:
                | 
                |         oD
                |             D Coefficient of cartesian plane 
                | 
                |     See also:
                |         Length 
                |     Returns:
                |         HRESULT S_OK if Ok E_FAIL else return error code for C++
                |         Implementations 
                |     See also:
                |         HybridShapeFactory

        :return: Length
        :rtype: Length
        """

        return Length(self.hybrid_shape_plane_equation.D)

    @property
    def ref_axis_system(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RefAxisSystem() As Reference
                | 
                |     Returns or Sets the reference Axis System for PlaneEquation
                |     feature.
                |     This data is not mandatory, if element is null, the absolute axis system is
                |     taken.
                |     When an element is given, X, Y and Z are considered in this Axis
                |     system.
                |     If reference point is not specified, X,Y and Z are measured from origin of
                |     this axis system.
                | 
                |     Example
                |     :
                |         This example retrieves in oRefAxis the reference Axis System for
                |         PlaneEquation feature.
                | 
                |          Dim oRefAxis As CATIAReference
                |          Set oRefAxis  = PlaneEquation.RefAxisSystem

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_plane_equation.RefAxisSystem)

    @ref_axis_system.setter
    def ref_axis_system(self, reference_axis: Reference):
        """
        :param Reference reference_axis:
        """

        self.hybrid_shape_plane_equation.RefAxisSystem = reference_axis

    def get_reference_point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetReferencePoint() As Reference
                | 
                |     Gets the reference point.
                | 
                |     Parameters:
                | 
                |         oReferencePoint
                |             reference point

        :return: Reference
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_plane_equation.GetReferencePoint())

    def set_reference_point(self, i_reference_point: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetReferencePoint(Reference iReferencePoint)
                | 
                |     Sets the reference point.
                | 
                |     Parameters:
                | 
                |         iReferencePoint
                |             reference point

        :param Reference i_reference_point:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_plane_equation.SetReferencePoint(i_reference_point.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_reference_point'
        # # vba_code = """
        # # Public Function set_reference_point(hybrid_shape_plane_equation)
        # #     Dim iReferencePoint (2)
        # #     hybrid_shape_plane_equation.SetReferencePoint iReferencePoint
        # #     set_reference_point = iReferencePoint
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'HybridShapePlaneEquation(name="{self.name}")'
